@@ -153,7 +153,7 @@ zenity_text (ZenityData *data, ZenityTextData *text_data)
   else
     gtk_window_set_default_size (GTK_WINDOW (dialog), 300, 400); 
 
-  gtk_widget_show (dialog);
+  zenity_util_show_dialog (dialog);
 
   if (glade_dialog)
     g_object_unref (glade_dialog);
@@ -175,7 +175,6 @@ zenity_text_dialog_response (GtkWidget *widget, int response, gpointer data)
         g_print (gtk_text_buffer_get_text (zen_text_data->buffer, &start, &end, 0));
       }
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
-      gtk_main_quit ();
       break;
 
     default:
@@ -183,4 +182,5 @@ zenity_text_dialog_response (GtkWidget *widget, int response, gpointer data)
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
       break;
   }
+  gtk_main_quit ();
 }
